@@ -1067,7 +1067,8 @@ end
                 x::Int
             end
             f = Fix{1}(MyStruct, 1)
-            @test f isa Fix{1,Type{MyStruct},Int}
+            @test f isa Fix{1}
+            @test f() === MyStruct(1)
         end
     end
 end
